summaryrefslogtreecommitdiff
path: root/programs/sub-suite/subeditor.s
diff options
context:
space:
mode:
Diffstat (limited to 'programs/sub-suite/subeditor.s')
-rw-r--r--programs/sub-suite/subeditor.s4
1 files changed, 2 insertions, 2 deletions
diff --git a/programs/sub-suite/subeditor.s b/programs/sub-suite/subeditor.s
index 2676a93..bec3f41 100644
--- a/programs/sub-suite/subeditor.s
+++ b/programs/sub-suite/subeditor.s
@@ -364,7 +364,7 @@ cmd_cpy:
sta (ptr2), y ; Copy one byte from the screen buffer, to the command buffer.
inx ; Increment the command buffer index.
ply.w ; Get back the screen index.
- cpx.w #$3FF ; Are we at the end of the command buffer?
+ cpx.w #CMDSIZE ; Are we at the end of the command buffer?
bcs @end ; Yes, so we're done.
iny ; No, so increment the screen index.
inb ; Increment the byte count.
@@ -579,7 +579,7 @@ clr_scr:
lda.q buffer ; Set the array to be cleared to the screen buffer.
jsr clr_arr ; Clear the screen buffer.
; tay ;
; lda.w #$3FF ; Set the clear count to $3FF.
; sta.w scr_ptr ;
; lda.d #cmd_buf ; Set the array to be cleared to the command buffer.
; jsr clr_arr ; Clear the screen buffer.
@@ -579,7 +579,7 @@ clr_scr:
jsr clr_arr ; Clear the screen buffer.
; tay ;
-; lda.w #$3FF ; Set the clear count to $3FF.
+; lda.w #CMDSIZE ; Set the clear count to CMDSIZE.
; sta.w scr_ptr ;
; lda.d #cmd_buf ; Set the array to be cleared to the command buffer.